==> kdebase-3.0.1.tar.bz2: kdebase-3.0.1/kcontrol/launch/kcmlaunch.h <==
/*
 *  Copyright (C) 2001 Rik Hemsley (rikkus) <rik@kde.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 */

#ifndef __kcmlaunch_h__
#define __kcmlaunch_h__

#include <kcmodule.h>

class QCheckBox;
class QSpinBox;
class QGroupBox;

class LaunchConfig : public KCModule
{
  Q_OBJECT

  public:

    LaunchConfig(QWidget * parent = 0, const char * name = 0, const QStringList &list = QStringList() );

    virtual ~LaunchConfig();

    void load();
    void save();
    void defaults();

    QString quickHelp() const;

  protected slots:

    void checkChanged();

  protected:

    enum FeedbackStyle
    {
      BusyCursor            = 1 << 0,
      TaskbarButton         = 1 << 1,

      Default = BusyCursor | TaskbarButton
    };


  private:

    QCheckBox * cb_busyCursor;
    QCheckBox * cb_busyBlinking;
    QCheckBox * cb_taskbarButton;
    QSpinBox  * sb_cursorTimeout;
    QSpinBox  * sb_taskbarTimeout;

};

#endif

==> kdebase-3.1.4.tar.bz2: kdebase-3.1.4/kcontrol/launch/kcmlaunch.h <==
/*
 *  Copyright (C) 2001 Rik Hemsley (rikkus) <rik@kde.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 */

#ifndef __kcmlaunch_h__
#define __kcmlaunch_h__

#include <kcmodule.h>

class QCheckBox;
//class QSpinBox;
class KIntNumInput;
class QGroupBox;

class LaunchConfig : public KCModule
{
  Q_OBJECT

  public:

    LaunchConfig(QWidget * parent = 0, const char * name = 0, const QStringList &list = QStringList() );

    virtual ~LaunchConfig();

    void load();
    void save();
    void defaults();

    QString quickHelp() const;

  protected slots:

    void checkChanged();
    void slotBusyCursor(bool);
    void slotTaskbarButton(bool);

  protected:

    enum FeedbackStyle
    {
      BusyCursor            = 1 << 0,
      TaskbarButton         = 1 << 1,

      Default = BusyCursor | TaskbarButton
    };


  private:

    QLabel    * lbl_cursorTimeout;
    QLabel    * lbl_taskbarTimeout;
    QCheckBox * cb_busyCursor;
    QCheckBox * cb_busyBlinking;
    QCheckBox * cb_taskbarButton;
    KIntNumInput * sb_cursorTimeout;
    KIntNumInput * sb_taskbarTimeout;

};

#endif
